# coding: utf-8

"""
    Managed Ray API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class OrganizationSummary(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'id': 'str',
        'public_identifier': 'str',
        'creator_email': 'str',
        'total_users': 'int'
    }

    attribute_map = {
        'name': 'name',
        'id': 'id',
        'public_identifier': 'public_identifier',
        'creator_email': 'creator_email',
        'total_users': 'total_users'
    }

    def __init__(self, name=None, id=None, public_identifier=None, creator_email=None, total_users=None, local_vars_configuration=None):  # noqa: E501
        """OrganizationSummary - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._id = None
        self._public_identifier = None
        self._creator_email = None
        self._total_users = None
        self.discriminator = None

        self.name = name
        self.id = id
        self.public_identifier = public_identifier
        self.creator_email = creator_email
        self.total_users = total_users

    @property
    def name(self):
        """Gets the name of this OrganizationSummary.  # noqa: E501


        :return: The name of this OrganizationSummary.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OrganizationSummary.


        :param name: The name of this OrganizationSummary.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def id(self):
        """Gets the id of this OrganizationSummary.  # noqa: E501


        :return: The id of this OrganizationSummary.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrganizationSummary.


        :param id: The id of this OrganizationSummary.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def public_identifier(self):
        """Gets the public_identifier of this OrganizationSummary.  # noqa: E501


        :return: The public_identifier of this OrganizationSummary.  # noqa: E501
        :rtype: str
        """
        return self._public_identifier

    @public_identifier.setter
    def public_identifier(self, public_identifier):
        """Sets the public_identifier of this OrganizationSummary.


        :param public_identifier: The public_identifier of this OrganizationSummary.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and public_identifier is None:  # noqa: E501
            raise ValueError("Invalid value for `public_identifier`, must not be `None`")  # noqa: E501

        self._public_identifier = public_identifier

    @property
    def creator_email(self):
        """Gets the creator_email of this OrganizationSummary.  # noqa: E501


        :return: The creator_email of this OrganizationSummary.  # noqa: E501
        :rtype: str
        """
        return self._creator_email

    @creator_email.setter
    def creator_email(self, creator_email):
        """Sets the creator_email of this OrganizationSummary.


        :param creator_email: The creator_email of this OrganizationSummary.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and creator_email is None:  # noqa: E501
            raise ValueError("Invalid value for `creator_email`, must not be `None`")  # noqa: E501

        self._creator_email = creator_email

    @property
    def total_users(self):
        """Gets the total_users of this OrganizationSummary.  # noqa: E501


        :return: The total_users of this OrganizationSummary.  # noqa: E501
        :rtype: int
        """
        return self._total_users

    @total_users.setter
    def total_users(self, total_users):
        """Sets the total_users of this OrganizationSummary.


        :param total_users: The total_users of this OrganizationSummary.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_users is None:  # noqa: E501
            raise ValueError("Invalid value for `total_users`, must not be `None`")  # noqa: E501

        self._total_users = total_users

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrganizationSummary):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrganizationSummary):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Managed Ray API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class InstanceUsageBudget(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'budget_amount': 'float',
        'evaluation_period': 'InstanceUsageBudgetEvaluationPeriod',
        'project_id': 'str',
        'cloud_id': 'str',
        'id': 'str',
        'creator_id': 'str',
        'creator': 'MiniUser',
        'organization_id': 'str',
        'curr_instance_usage_in_dollars': 'float',
        'created_at': 'datetime',
        'deleted_at': 'datetime',
        'is_enabled': 'bool',
        'last_notified_at': 'datetime',
        'last_usage_updated_at': 'datetime'
    }

    attribute_map = {
        'name': 'name',
        'budget_amount': 'budget_amount',
        'evaluation_period': 'evaluation_period',
        'project_id': 'project_id',
        'cloud_id': 'cloud_id',
        'id': 'id',
        'creator_id': 'creator_id',
        'creator': 'creator',
        'organization_id': 'organization_id',
        'curr_instance_usage_in_dollars': 'curr_instance_usage_in_dollars',
        'created_at': 'created_at',
        'deleted_at': 'deleted_at',
        'is_enabled': 'is_enabled',
        'last_notified_at': 'last_notified_at',
        'last_usage_updated_at': 'last_usage_updated_at'
    }

    def __init__(self, name=None, budget_amount=None, evaluation_period=None, project_id=None, cloud_id=None, id=None, creator_id=None, creator=None, organization_id=None, curr_instance_usage_in_dollars=None, created_at=None, deleted_at=None, is_enabled=None, last_notified_at=None, last_usage_updated_at=None, local_vars_configuration=None):  # noqa: E501
        """InstanceUsageBudget - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._budget_amount = None
        self._evaluation_period = None
        self._project_id = None
        self._cloud_id = None
        self._id = None
        self._creator_id = None
        self._creator = None
        self._organization_id = None
        self._curr_instance_usage_in_dollars = None
        self._created_at = None
        self._deleted_at = None
        self._is_enabled = None
        self._last_notified_at = None
        self._last_usage_updated_at = None
        self.discriminator = None

        self.name = name
        self.budget_amount = budget_amount
        self.evaluation_period = evaluation_period
        if project_id is not None:
            self.project_id = project_id
        if cloud_id is not None:
            self.cloud_id = cloud_id
        self.id = id
        self.creator_id = creator_id
        self.creator = creator
        self.organization_id = organization_id
        self.curr_instance_usage_in_dollars = curr_instance_usage_in_dollars
        self.created_at = created_at
        if deleted_at is not None:
            self.deleted_at = deleted_at
        self.is_enabled = is_enabled
        if last_notified_at is not None:
            self.last_notified_at = last_notified_at
        if last_usage_updated_at is not None:
            self.last_usage_updated_at = last_usage_updated_at

    @property
    def name(self):
        """Gets the name of this InstanceUsageBudget.  # noqa: E501


        :return: The name of this InstanceUsageBudget.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InstanceUsageBudget.


        :param name: The name of this InstanceUsageBudget.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def budget_amount(self):
        """Gets the budget_amount of this InstanceUsageBudget.  # noqa: E501


        :return: The budget_amount of this InstanceUsageBudget.  # noqa: E501
        :rtype: float
        """
        return self._budget_amount

    @budget_amount.setter
    def budget_amount(self, budget_amount):
        """Sets the budget_amount of this InstanceUsageBudget.


        :param budget_amount: The budget_amount of this InstanceUsageBudget.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and budget_amount is None:  # noqa: E501
            raise ValueError("Invalid value for `budget_amount`, must not be `None`")  # noqa: E501

        self._budget_amount = budget_amount

    @property
    def evaluation_period(self):
        """Gets the evaluation_period of this InstanceUsageBudget.  # noqa: E501


        :return: The evaluation_period of this InstanceUsageBudget.  # noqa: E501
        :rtype: InstanceUsageBudgetEvaluationPeriod
        """
        return self._evaluation_period

    @evaluation_period.setter
    def evaluation_period(self, evaluation_period):
        """Sets the evaluation_period of this InstanceUsageBudget.


        :param evaluation_period: The evaluation_period of this InstanceUsageBudget.  # noqa: E501
        :type: InstanceUsageBudgetEvaluationPeriod
        """
        if self.local_vars_configuration.client_side_validation and evaluation_period is None:  # noqa: E501
            raise ValueError("Invalid value for `evaluation_period`, must not be `None`")  # noqa: E501

        self._evaluation_period = evaluation_period

    @property
    def project_id(self):
        """Gets the project_id of this InstanceUsageBudget.  # noqa: E501


        :return: The project_id of this InstanceUsageBudget.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this InstanceUsageBudget.


        :param project_id: The project_id of this InstanceUsageBudget.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def cloud_id(self):
        """Gets the cloud_id of this InstanceUsageBudget.  # noqa: E501


        :return: The cloud_id of this InstanceUsageBudget.  # noqa: E501
        :rtype: str
        """
        return self._cloud_id

    @cloud_id.setter
    def cloud_id(self, cloud_id):
        """Sets the cloud_id of this InstanceUsageBudget.


        :param cloud_id: The cloud_id of this InstanceUsageBudget.  # noqa: E501
        :type: str
        """

        self._cloud_id = cloud_id

    @property
    def id(self):
        """Gets the id of this InstanceUsageBudget.  # noqa: E501


        :return: The id of this InstanceUsageBudget.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InstanceUsageBudget.


        :param id: The id of this InstanceUsageBudget.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def creator_id(self):
        """Gets the creator_id of this InstanceUsageBudget.  # noqa: E501


        :return: The creator_id of this InstanceUsageBudget.  # noqa: E501
        :rtype: str
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id):
        """Sets the creator_id of this InstanceUsageBudget.


        :param creator_id: The creator_id of this InstanceUsageBudget.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and creator_id is None:  # noqa: E501
            raise ValueError("Invalid value for `creator_id`, must not be `None`")  # noqa: E501

        self._creator_id = creator_id

    @property
    def creator(self):
        """Gets the creator of this InstanceUsageBudget.  # noqa: E501


        :return: The creator of this InstanceUsageBudget.  # noqa: E501
        :rtype: MiniUser
        """
        return self._creator

    @creator.setter
    def creator(self, creator):
        """Sets the creator of this InstanceUsageBudget.


        :param creator: The creator of this InstanceUsageBudget.  # noqa: E501
        :type: MiniUser
        """
        if self.local_vars_configuration.client_side_validation and creator is None:  # noqa: E501
            raise ValueError("Invalid value for `creator`, must not be `None`")  # noqa: E501

        self._creator = creator

    @property
    def organization_id(self):
        """Gets the organization_id of this InstanceUsageBudget.  # noqa: E501


        :return: The organization_id of this InstanceUsageBudget.  # noqa: E501
        :rtype: str
        """
        return self._organization_id

    @organization_id.setter
    def organization_id(self, organization_id):
        """Sets the organization_id of this InstanceUsageBudget.


        :param organization_id: The organization_id of this InstanceUsageBudget.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and organization_id is None:  # noqa: E501
            raise ValueError("Invalid value for `organization_id`, must not be `None`")  # noqa: E501

        self._organization_id = organization_id

    @property
    def curr_instance_usage_in_dollars(self):
        """Gets the curr_instance_usage_in_dollars of this InstanceUsageBudget.  # noqa: E501


        :return: The curr_instance_usage_in_dollars of this InstanceUsageBudget.  # noqa: E501
        :rtype: float
        """
        return self._curr_instance_usage_in_dollars

    @curr_instance_usage_in_dollars.setter
    def curr_instance_usage_in_dollars(self, curr_instance_usage_in_dollars):
        """Sets the curr_instance_usage_in_dollars of this InstanceUsageBudget.


        :param curr_instance_usage_in_dollars: The curr_instance_usage_in_dollars of this InstanceUsageBudget.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and curr_instance_usage_in_dollars is None:  # noqa: E501
            raise ValueError("Invalid value for `curr_instance_usage_in_dollars`, must not be `None`")  # noqa: E501

        self._curr_instance_usage_in_dollars = curr_instance_usage_in_dollars

    @property
    def created_at(self):
        """Gets the created_at of this InstanceUsageBudget.  # noqa: E501


        :return: The created_at of this InstanceUsageBudget.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InstanceUsageBudget.


        :param created_at: The created_at of this InstanceUsageBudget.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def deleted_at(self):
        """Gets the deleted_at of this InstanceUsageBudget.  # noqa: E501


        :return: The deleted_at of this InstanceUsageBudget.  # noqa: E501
        :rtype: datetime
        """
        return self._deleted_at

    @deleted_at.setter
    def deleted_at(self, deleted_at):
        """Sets the deleted_at of this InstanceUsageBudget.


        :param deleted_at: The deleted_at of this InstanceUsageBudget.  # noqa: E501
        :type: datetime
        """

        self._deleted_at = deleted_at

    @property
    def is_enabled(self):
        """Gets the is_enabled of this InstanceUsageBudget.  # noqa: E501


        :return: The is_enabled of this InstanceUsageBudget.  # noqa: E501
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """Sets the is_enabled of this InstanceUsageBudget.


        :param is_enabled: The is_enabled of this InstanceUsageBudget.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and is_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `is_enabled`, must not be `None`")  # noqa: E501

        self._is_enabled = is_enabled

    @property
    def last_notified_at(self):
        """Gets the last_notified_at of this InstanceUsageBudget.  # noqa: E501


        :return: The last_notified_at of this InstanceUsageBudget.  # noqa: E501
        :rtype: datetime
        """
        return self._last_notified_at

    @last_notified_at.setter
    def last_notified_at(self, last_notified_at):
        """Sets the last_notified_at of this InstanceUsageBudget.


        :param last_notified_at: The last_notified_at of this InstanceUsageBudget.  # noqa: E501
        :type: datetime
        """

        self._last_notified_at = last_notified_at

    @property
    def last_usage_updated_at(self):
        """Gets the last_usage_updated_at of this InstanceUsageBudget.  # noqa: E501


        :return: The last_usage_updated_at of this InstanceUsageBudget.  # noqa: E501
        :rtype: datetime
        """
        return self._last_usage_updated_at

    @last_usage_updated_at.setter
    def last_usage_updated_at(self, last_usage_updated_at):
        """Sets the last_usage_updated_at of this InstanceUsageBudget.


        :param last_usage_updated_at: The last_usage_updated_at of this InstanceUsageBudget.  # noqa: E501
        :type: datetime
        """

        self._last_usage_updated_at = last_usage_updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstanceUsageBudget):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InstanceUsageBudget):
            return True

        return self.to_dict() != other.to_dict()



"""Entrypoint to generate reference docs for the Anyscale CLI/SDK.

Usage: python -m anyscale._private.docgen --help
"""
import os

import click

import anyscale
from anyscale._private.docgen.generator import MarkdownGenerator, Module
from anyscale.commands import (
    cloud_commands,
    compute_config_commands,
    image_commands,
    job_commands,
    logs_commands,
    schedule_commands,
    service_account_commands,
    service_commands,
    workspace_commands_v2,
)
from anyscale.compute_config.models import (
    ComputeConfig,
    ComputeConfigVersion,
    HeadNodeConfig,
    MarketType,
    WorkerNodeGroupConfig,
)
from anyscale.image.models import ImageBuild, ImageBuildStatus
from anyscale.job.models import (
    JobConfig,
    JobLogMode,
    JobQueueConfig,
    JobQueueExecutionMode,
    JobQueueSpec,
    JobRunState,
    JobRunStatus,
    JobState,
    JobStatus,
)
from anyscale.schedule.models import ScheduleConfig, ScheduleState, ScheduleStatus
from anyscale.service.models import (
    RayGCSExternalStorageConfig,
    ServiceConfig,
    ServiceState,
    ServiceStatus,
    ServiceVersionState,
    ServiceVersionStatus,
    TracingConfig,
)
from anyscale.workspace.models import WorkspaceConfig


# Defines all modules to be documented.
ALL_MODULES = [
    Module(
        title="Job",
        filename="job-api.md",
        cli_prefix="anyscale job",
        cli_commands=[
            job_commands.submit,
            job_commands.status,
            job_commands.terminate,
            job_commands.archive,
            job_commands.logs,
            job_commands.wait,
            job_commands.list,
        ],
        sdk_prefix="anyscale.job",
        sdk_commands=[
            anyscale.job.submit,
            anyscale.job.status,
            anyscale.job.terminate,
            anyscale.job.archive,
            anyscale.job.get_logs,
            anyscale.job.wait,
        ],
        models=[
            JobQueueSpec,
            JobQueueConfig,
            JobQueueExecutionMode,
            JobConfig,
            JobState,
            JobStatus,
            JobRunStatus,
            JobRunState,
            JobLogMode,
        ],
    ),
    Module(
        title="Schedule",
        filename="schedule-api.md",
        cli_prefix="anyscale schedule",
        cli_commands=[
            schedule_commands.create,
            schedule_commands.update,
            schedule_commands.apply,
            schedule_commands.list,
            schedule_commands.pause,
            schedule_commands.resume,
            schedule_commands.status,
            schedule_commands.trigger,
            schedule_commands.url,
        ],
        sdk_prefix="anyscale.schedule",
        sdk_commands=[
            anyscale.schedule.apply,
            anyscale.schedule.set_state,
            anyscale.schedule.status,
            anyscale.schedule.trigger,
        ],
        models=[ScheduleConfig, ScheduleState, ScheduleStatus],
    ),
    Module(
        title="Service",
        filename="service-api.md",
        cli_prefix="anyscale service",
        cli_commands=[
            service_commands.deploy,
            service_commands.status,
            service_commands.wait,
            service_commands.rollback,
            service_commands.terminate,
        ],
        sdk_prefix="anyscale.service",
        sdk_commands=[
            anyscale.service.deploy,
            anyscale.service.status,
            anyscale.service.wait,
            anyscale.service.rollback,
            anyscale.service.terminate,
        ],
        models=[
            ServiceConfig,
            RayGCSExternalStorageConfig,
            TracingConfig,
            ServiceStatus,
            ServiceState,
            ServiceVersionStatus,
            ServiceVersionState,
        ],
    ),
    Module(
        title="Compute Config",
        filename="compute-config-api.md",
        cli_prefix="anyscale compute-config",
        cli_commands=[
            compute_config_commands.create_compute_config,
            compute_config_commands.get_compute_config,
            compute_config_commands.archive_compute_config,
        ],
        sdk_prefix="anyscale.compute_config",
        sdk_commands=[
            anyscale.compute_config.create,
            anyscale.compute_config.get,
            anyscale.compute_config.archive,
        ],
        models=[
            ComputeConfig,
            HeadNodeConfig,
            WorkerNodeGroupConfig,
            MarketType,
            ComputeConfigVersion,
        ],
    ),
    Module(
        title="Service Account",
        filename="service-account.md",
        cli_prefix="anyscale service-account",
        cli_commands=[
            service_account_commands.create,
            service_account_commands.create_api_key,
            service_account_commands.list_service_accounts,
            service_account_commands.delete,
            service_account_commands.rotate_api_keys,
        ],
        sdk_prefix="anyscale.service_account",
        sdk_commands=[],
        models=[],
    ),
    Module(
        title="Image",
        filename="image.md",
        cli_prefix="anyscale image",
        cli_commands=[image_commands.build, image_commands.get,],
        sdk_prefix="anyscale.image",
        sdk_commands=[anyscale.image.build, anyscale.image.get,],
        models=[ImageBuild, ImageBuildStatus],
    ),
    Module(
        title="Cloud",
        filename="cloud.md",
        cli_prefix="anyscale cloud",
        cli_commands=[
            cloud_commands.setup_cloud,
            cloud_commands.register_cloud,
            cloud_commands.cloud_edit,
            cloud_commands.cloud_update,
            cloud_commands.cloud_delete,
            cloud_commands.cloud_verify,
            cloud_commands.list_cloud,
            cloud_commands.cloud_config_update,
        ],
        sdk_prefix="anyscale.cloud",
        sdk_commands=[],
        models=[],
        cli_command_group_prefix={cloud_commands.cloud_config_update: "config"},
    ),
    Module(
        title="Logs",
        filename="logs.md",
        cli_prefix="anyscale logs",
        cli_commands=[logs_commands.anyscale_logs_cluster],
        sdk_prefix="anyscale.logs",
        sdk_commands=[],
        models=[],
    ),
    Module(
        title="Workspaces",
        filename="workspaces.md",
        cli_prefix="anyscale workspace_v2",
        cli_commands=[
            workspace_commands_v2.create,
            workspace_commands_v2.start,
            workspace_commands_v2.terminate,
            workspace_commands_v2.status,
            workspace_commands_v2.wait,
            workspace_commands_v2.ssh,
            workspace_commands_v2.run_command,
        ],
        sdk_prefix="anyscale.workspace",
        sdk_commands=[
            anyscale.workspace.create,
            anyscale.workspace.start,
            anyscale.workspace.terminate,
            anyscale.workspace.status,
            anyscale.workspace.wait,
            anyscale.workspace.generate_ssh_config_file,
            anyscale.workspace.run_command,
        ],
        models=[WorkspaceConfig],
    ),
]


@click.command(help="Generate markdown docs for the Anyscale CLI & SDK.")
@click.argument("output_dir")
@click.option(
    "-r",
    "--remove-existing",
    is_flag=True,
    default=False,
    help="If set, all files in the 'output_dir' that were not generated will be removed.",
)
def generate(
    output_dir: str, *, remove_existing: bool = False,
):
    if not os.path.isdir(output_dir):
        raise RuntimeError(f"output_dir '{output_dir}' does not exist.")

    gen = MarkdownGenerator(ALL_MODULES)
    gen.generate()

    generated_files = set()
    os.makedirs(output_dir, exist_ok=True)
    for filename, content in gen.generate().items():
        generated_files.add(filename)
        full_path = os.path.join(output_dir, filename)
        print(f"Writing output file {full_path}")
        with open(full_path, "w") as f:
            f.write(content)

    if remove_existing:
        to_remove = set(os.listdir(output_dir)) - generated_files
        for path in to_remove:
            full_path = os.path.join(output_dir, path)
            print(f"Removing existing file {full_path}")
            os.unlink(full_path)


if __name__ == "__main__":
    generate()



# coding: utf-8

"""
    Managed Ray API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class AicaModelConfiguration(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'title': 'str',
        'supported_clouds': 'list[CloudProviders]',
        'model_config': 'object',
        'model_compute_config': 'dict(str, list[object])'
    }

    attribute_map = {
        'title': 'title',
        'supported_clouds': 'supported_clouds',
        'model_config': 'model_config',
        'model_compute_config': 'model_compute_config'
    }

    def __init__(self, title=None, supported_clouds=None, model_config=None, model_compute_config=None, local_vars_configuration=None):  # noqa: E501
        """AicaModelConfiguration - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._title = None
        self._supported_clouds = None
        self._model_config = None
        self._model_compute_config = None
        self.discriminator = None

        self.title = title
        self.supported_clouds = supported_clouds
        self.model_config = model_config
        if model_compute_config is not None:
            self.model_compute_config = model_compute_config

    @property
    def title(self):
        """Gets the title of this AicaModelConfiguration.  # noqa: E501

        Model configuration title  # noqa: E501

        :return: The title of this AicaModelConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this AicaModelConfiguration.

        Model configuration title  # noqa: E501

        :param title: The title of this AicaModelConfiguration.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and title is None:  # noqa: E501
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    @property
    def supported_clouds(self):
        """Gets the supported_clouds of this AicaModelConfiguration.  # noqa: E501

        List of clouds that support this model configuration  # noqa: E501

        :return: The supported_clouds of this AicaModelConfiguration.  # noqa: E501
        :rtype: list[CloudProviders]
        """
        return self._supported_clouds

    @supported_clouds.setter
    def supported_clouds(self, supported_clouds):
        """Sets the supported_clouds of this AicaModelConfiguration.

        List of clouds that support this model configuration  # noqa: E501

        :param supported_clouds: The supported_clouds of this AicaModelConfiguration.  # noqa: E501
        :type: list[CloudProviders]
        """
        if self.local_vars_configuration.client_side_validation and supported_clouds is None:  # noqa: E501
            raise ValueError("Invalid value for `supported_clouds`, must not be `None`")  # noqa: E501

        self._supported_clouds = supported_clouds

    @property
    def model_config(self):
        """Gets the model_config of this AicaModelConfiguration.  # noqa: E501

        Model configuration  # noqa: E501

        :return: The model_config of this AicaModelConfiguration.  # noqa: E501
        :rtype: object
        """
        return self._model_config

    @model_config.setter
    def model_config(self, model_config):
        """Sets the model_config of this AicaModelConfiguration.

        Model configuration  # noqa: E501

        :param model_config: The model_config of this AicaModelConfiguration.  # noqa: E501
        :type: object
        """
        if self.local_vars_configuration.client_side_validation and model_config is None:  # noqa: E501
            raise ValueError("Invalid value for `model_config`, must not be `None`")  # noqa: E501

        self._model_config = model_config

    @property
    def model_compute_config(self):
        """Gets the model_compute_config of this AicaModelConfiguration.  # noqa: E501

        Compute configuration  # noqa: E501

        :return: The model_compute_config of this AicaModelConfiguration.  # noqa: E501
        :rtype: dict(str, list[object])
        """
        return self._model_compute_config

    @model_compute_config.setter
    def model_compute_config(self, model_compute_config):
        """Sets the model_compute_config of this AicaModelConfiguration.

        Compute configuration  # noqa: E501

        :param model_compute_config: The model_compute_config of this AicaModelConfiguration.  # noqa: E501
        :type: dict(str, list[object])
        """

        self._model_compute_config = model_compute_config

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AicaModelConfiguration):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AicaModelConfiguration):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Managed Ray API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class TryLoginEmailResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'email_address': 'str',
        'create_new_org': 'bool',
        'organizations': 'list[OrganizationSummary]',
        'invite_code': 'str'
    }

    attribute_map = {
        'email_address': 'email_address',
        'create_new_org': 'create_new_org',
        'organizations': 'organizations',
        'invite_code': 'invite_code'
    }

    def __init__(self, email_address=None, create_new_org=None, organizations=None, invite_code=None, local_vars_configuration=None):  # noqa: E501
        """TryLoginEmailResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._email_address = None
        self._create_new_org = None
        self._organizations = None
        self._invite_code = None
        self.discriminator = None

        self.email_address = email_address
        self.create_new_org = create_new_org
        if organizations is not None:
            self.organizations = organizations
        if invite_code is not None:
            self.invite_code = invite_code

    @property
    def email_address(self):
        """Gets the email_address of this TryLoginEmailResponse.  # noqa: E501

        The email address that the user is trying to log in with  # noqa: E501

        :return: The email_address of this TryLoginEmailResponse.  # noqa: E501
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this TryLoginEmailResponse.

        The email address that the user is trying to log in with  # noqa: E501

        :param email_address: The email_address of this TryLoginEmailResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and email_address is None:  # noqa: E501
            raise ValueError("Invalid value for `email_address`, must not be `None`")  # noqa: E501

        self._email_address = email_address

    @property
    def create_new_org(self):
        """Gets the create_new_org of this TryLoginEmailResponse.  # noqa: E501

        When email has not been used yet, we send user to create a new org  # noqa: E501

        :return: The create_new_org of this TryLoginEmailResponse.  # noqa: E501
        :rtype: bool
        """
        return self._create_new_org

    @create_new_org.setter
    def create_new_org(self, create_new_org):
        """Sets the create_new_org of this TryLoginEmailResponse.

        When email has not been used yet, we send user to create a new org  # noqa: E501

        :param create_new_org: The create_new_org of this TryLoginEmailResponse.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and create_new_org is None:  # noqa: E501
            raise ValueError("Invalid value for `create_new_org`, must not be `None`")  # noqa: E501

        self._create_new_org = create_new_org

    @property
    def organizations(self):
        """Gets the organizations of this TryLoginEmailResponse.  # noqa: E501

        When logging in as an existing user, there could be one or multiple organizations to log in to  # noqa: E501

        :return: The organizations of this TryLoginEmailResponse.  # noqa: E501
        :rtype: list[OrganizationSummary]
        """
        return self._organizations

    @organizations.setter
    def organizations(self, organizations):
        """Sets the organizations of this TryLoginEmailResponse.

        When logging in as an existing user, there could be one or multiple organizations to log in to  # noqa: E501

        :param organizations: The organizations of this TryLoginEmailResponse.  # noqa: E501
        :type: list[OrganizationSummary]
        """

        self._organizations = organizations

    @property
    def invite_code(self):
        """Gets the invite_code of this TryLoginEmailResponse.  # noqa: E501

        Invite code to use when creating a new organization. Only present when create_new_org is true and the user registers through a url with an invite code.  # noqa: E501

        :return: The invite_code of this TryLoginEmailResponse.  # noqa: E501
        :rtype: str
        """
        return self._invite_code

    @invite_code.setter
    def invite_code(self, invite_code):
        """Sets the invite_code of this TryLoginEmailResponse.

        Invite code to use when creating a new organization. Only present when create_new_org is true and the user registers through a url with an invite code.  # noqa: E501

        :param invite_code: The invite_code of this TryLoginEmailResponse.  # noqa: E501
        :type: str
        """

        self._invite_code = invite_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TryLoginEmailResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TryLoginEmailResponse):
            return True

        return self.to_dict() != other.to_dict()
